package `in`.finbox.deviceconnect.finbox_dc_plugin

import `in`.finbox.mobileriskmanager.FinBox
import `in`.finbox.mobileriskmanager.common.annotations.FinBoxErrorCode
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** FinBoxDcPlugin */
class FinBoxDcPlugin : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var deviceConnectChannel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        deviceConnectChannel =
            MethodChannel(flutterPluginBinding.binaryMessenger, "in.finbox.lending/deviceconnect")
        deviceConnectChannel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "launchDeviceConnect") {
            FinBox.createUser(
                call.argument("api_key")!!, call.argument("customer_id")!!,
                object : FinBox.FinBoxAuthCallback {
                    override fun onSuccess(accessToken: String) {
                        // Set up the data Sync
                        // Sync the data periodically
                        val finBox = FinBox()
                        finBox.startPeriodicSync()
                        result.success(accessToken)
                    }

                    override fun onError(@FinBoxErrorCode errorCode: Int) {
                        result.error(errorCode.toString(), "Refer https://docs.finbox.in/device-connect/android.html#error-codes", null)
                    }
                })
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        deviceConnectChannel.setMethodCallHandler(null)
    }
}
